==> haskell-chell-0.4.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.4.0.2
id: chell-0.4.0.2-IBEdUKBRClqKXzybYpE5yx
key: chell-0.4.0.2-IBEdUKBRClqKXzybYpE5yx
license: MIT
maintainer: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
author: John Millikin <john@john-millikin.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
abi: f6aea355eaf10dda1ca06f6c0e6f58f6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/chell-0.4.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/chell-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/chell-0.4.0.2
hs-libraries: HSchell-0.4.0.2-IBEdUKBRClqKXzybYpE5yx
depends:
    ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7 base-4.10.1.0
    bytestring-0.10.8.2 options-1.2.1.1-38ZYPRuihX1Fh9IdUi6nBd
    patience-0.1.1-26vcEH4XVheD55wNjzC8dW
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We template-haskell-2.12.0.0
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
abi-depends: ansi-terminal-0.7.1.1-Dkv5Hnnkl1H2BxNaCxi8q7=90aaa595726b3421fbff142dea995314
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             options-1.2.1.1-38ZYPRuihX1Fh9IdUi6nBd=2d6b00b5271768615f417d3a3077f2f6
             patience-0.1.1-26vcEH4XVheD55wNjzC8dW=0cea22522a81db0a6266739b72f691c7
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.4.0.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell
version: 0.4.0.2
id: chell-0.4.0.2-J4Lqsli9gIMKxey18jsmVu
key: chell-0.4.0.2-J4Lqsli9gIMKxey18jsmVu
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing. It natively
    supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.
    .
    An example test suite, which verifies the behavior of artithmetic operators.
    .
    @
    &#x7b;-\# LANGUAGE TemplateHaskell \#-&#x7d;
    .
    import Test.Chell
    .
    tests_Math :: Suite
    tests_Math = suite \"math\"
    &#x20;   [ test_Addition
    &#x20;   , test_Subtraction
    &#x20;   ]
    .
    test_Addition :: Test
    test_Addition = assertions \"addition\" $ do
    &#x20;   $expect (equal (2 + 1) 3)
    &#x20;   $expect (equal (1 + 2) 3)
    .
    test_Subtraction :: Test
    test_Subtraction = assertions \"subtraction\" $ do
    &#x20;   $expect (equal (2 - 1) 1)
    &#x20;   $expect (equal (1 - 2) (-1))
    .
    main :: IO ()
    main = defaultMain [tests_Math]
    @
    .
    @
    $ ghc --make chell-example.hs
    $ ./chell-example
    PASS: 2 tests run, 2 tests passed
    @
category: Testing
abi: 146e65264c0dd8a02b8e6d7979aba2c3
exposed: True
exposed-modules:
    Test.Chell
hidden-modules: Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs: /usr/lib/ghc-8.4.2/site-local/chell-0.4.0.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/chell-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/chell-0.4.0.2
hs-libraries: HSchell-0.4.0.2-J4Lqsli9gIMKxey18jsmVu
depends:
    ansi-terminal-0.8.0.4-CvDyNcwxO3756EDj7fON2h base-4.11.1.0
    bytestring-0.10.8.2 options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL
    patience-0.1.1-ByieOh635rzAIvJxHEy8CG
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV template-haskell-2.13.0.0
    text-1.2.3.0 transformers-0.5.5.0
abi-depends: ansi-terminal-0.8.0.4-CvDyNcwxO3756EDj7fON2h=d29a802384bc8c994c84a39efa43ccae
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             options-1.2.1.1-8yUchvvR2SaHY7Vem0H7pL=50801a5f7c147043a0f7501129b4369a
             patience-0.1.1-ByieOh635rzAIvJxHEy8CG=79e39c980253f5645526dc33f5562ac4
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=552cb76a5e53a808564c851a382c09ce
             template-haskell-2.13.0.0=b25d144eee230069f091d0d8982b331b
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
haddock-interfaces: /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html: /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
